@@ -198,6 +198,9 @@ class Exchange:
             # the two vertices representing directed (paired) donors.
             if self.chain:
                 for exchange in self.alternates:
+                    # Backarc must have length 2
+                    if len(exchange) != 2:
+                        continue
                     if set(exchange.all_recipients()) == recipients:
                         backarc_exchanges.append(exchange)
                         break
