@@ -127,11 +127,11 @@ class EffectiveTwoWay(Objective):
         :param exchange: A cycle or chain.
         :return: 1 if and only if it is effectively two-way
         """
-        if exchange[0].isNdd():
-            return 1
         if len(exchange) == 2:
             return 1
-        if len(exchange) == 3 and exchange.num_backarcs_uk() >= 1:
+        if len(exchange) == 3 and (
+            exchange.num_backarcs_uk() >= 1 or exchange[0].isNdd()
+        ):
             return 1
         return 0
 
