@@ -31,6 +31,16 @@ def test_transplant_count_test1(transplant_pool):
     assert output == expected
 
 
+def test_transplant_count_test9(transplant_pool):
+    instance = fileio.read_json("tests/test_instances/test9.json")
+    solution, model = transplant_pool.solve_single(instance)
+    json_obj = fileio.UKJson(model, transplant_pool, solution)
+    output = json_obj.to_string()
+    with open("tests/test_instances/test9_output.json", "r") as infile:
+        expected = infile.read().rstrip()
+    assert output == expected
+
+
 def test_transplant_count_test10(transplant_pool):
     instance = fileio.read_json("tests/test_instances/test10.json")
     solution, model = transplant_pool.solve_single(instance)
